# backends name

MAILCHIMP_BACKEND_NAME = 'mailchimp'
SENDINBLUE_BACKEND_NAME = 'sendinblue'
HTML_BACKEND_NAME = 'html_email'
TWILIO_BACKEND_NAME = 'twilio'

# Backends types

SMS_BACKEND = "sms_backend"
EMAIL_BACKEND = "email_backend"
